"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = BarcodeScanner;

var _utils = require("./utils");

/**
 * Simple JavaScript utility to listen for barcode scanners emulating keyboard
 */
function BarcodeScanner(options) {
  var fun = void 0;
  options = (0, _utils.assign)({
    latency: 50,
    minLength: 3,
    element: document.documentElement,
    endKeys: [8, 9, 13, 32, 34, 39, 40, 41, 43],
    validKey: /[a-zA-Z0-9-_+]/,
    preventDefault: true,
    stopPropagation: true
  }, options);
  var prevTime = Date.now();
  var code = "";

  function EventHandler(e) {
    var keyCode = e.keyCode;
    var currTime = Date.now();
    var input = String.fromCharCode(keyCode);
    var isValid = options.validKey.test(input);
    var isEndKey = options.endKeys.includes(keyCode);
    var timeDiff = currTime - prevTime;
    prevTime = currTime;

    if (timeDiff > options.latency) {
      if (!isEndKey && isValid) {
        code = input;
      } else code = "";
    } else if (isEndKey) {
      if (code.length >= options.minLength) {
        fun && fun(code);
      }

      code = "";
      if (options.preventDefault) e.preventDefault();
      if (options.stopPropagation) e.stopPropagation();
    } else if (isValid) code += input;
  }

  return {
    on: function on(handler) {
      fun = handler;
      options.element.addEventListener("keydown", EventHandler, true);
    },
    off: function off() {
      fun = undefined;
      options.element.removeEventListener("keydown", EventHandler, true);
    }
  };
}